function h = plot_flow(Dx,Dy,rate)
% PLOT_FLOW
%   Dx          - x-component of flow vector.
%   Dy          - y-component of flow vector.
%   rate        - Sampling rate.
%
% RETURN
%   h           - Handle to plot of vectors.
%
% EXAMPLE
%   - Plotting of vector flow field denoted by (Dx,Dy):
%       Dx = ones(10);
%       Dy = rand(10);
%       figure;
%       plot_flow(Dx,Dy,1);
%

scale = 1;

[height width] = size(Dx);
[Y X] = ndgrid(1:height, 1:width);
color = 'k';

X = X(1:rate:end, 1:rate:end);
Y = Y(1:rate:end, 1:rate:end);
Dx = Dx(1:rate:end, 1:rate:end);
Dy = Dy(1:rate:end, 1:rate:end);

if scale==0,
  autoscale = 1;
  % Base autoscale value on average spacing in the x and y
  % directions.  Estimate number of points in each direction as
  % either the size of the input arrays or the effective square
  % spacing if x and y are vectors.
  if min(size(X))==1, n=sqrt(numel(X)); m=n; else [m,n]=size(X); end
  delx = diff([min(X(:)) max(X(:))])/n;
  dely = diff([min(Y(:)) max(Y(:))])/m;
  del = delx.^2 + dely.^2;
  if del>0
    len = sqrt((Dx.^2 + Dy.^2)/del);
    maxlen = max(len(:));
  else
    maxlen = 0;
  end
  
  if maxlen>0
    autoscale = autoscale*0.9 / maxlen;
  else
    autoscale = autoscale*0.9;
  end
  scale = autoscale;
end
Dx = Dx*scale; Dy = Dy*scale;

alpha = 20/180*pi;
X = X(:)'; Y = Y(:)';
Dx = Dx(:)'; Dy = Dy(:)';
L = sqrt(Dx.^2+Dy.^2);
l = max(L);
L = sqrt(L/(l+eps))*l; % Area proportional to length. Rescale with max(L).
L = 1.5 * L;
Phi = atan2(Dy, Dx);
cosPhi = cos(Phi);
sinPhi = sin(Phi);
X1 = L/2 .* cosPhi;
Y1 = L/2 .* sinPhi;
X2 = -L/2 .* cosPhi - L * tan(alpha/2) .* sinPhi;
Y2 = -L/2 .* sinPhi + L * tan(alpha/2) .* cosPhi;
X3 = -L/2 .* cosPhi + L * tan(alpha/2) .* sinPhi;
Y3 = -L/2 .* sinPhi - L * tan(alpha/2) .* cosPhi;
Hx = [X1; X2; X3; X1] + repmat(X, [4 1]);
Hy = [Y1; Y2; Y3; Y1] + repmat(Y, [4 1]);
hold(gca,'on');
h = fill(Hx,Hy,color,'EdgeColor','none');


set(gca,'Box','on');
% drop ticks
set(gca,'TickLength',[0 0]);
% drop axis numbers
set(gca,'YTick',[]);
set(gca,'XTick',[]);
axis equal tight ij;
hold off;
